@@ -1,27 +1,20 @@
 '''Simple messaging with RabbitMQ and Python.'''
 
-__version__ = '0.0.8'
+__version__ = '0.0.10'
 
 import logging
 import pickle
 import time
-from hashlib import md5
 
 import pika
 
 log = logging.getLogger(__name__)
 log.addHandler(logging.NullHandler())
 
-Errors = (
-    pika.exceptions.StreamLostError,
-    pika.exceptions.ConnectionClosed,
-    pika.exceptions.ChannelClosed,
-    pika.exceptions.ChannelWrongStateError,
-)
-
 
 class Queue:
     max_priority = 10
+    heartbeat_interval = 600  # 10 min, default 1 min is too low
     
     def __init__(self, name, host='localhost', port=5672, vhost='/', username='guest', password='guest', max_retries=100, retry_interval=5):
         name = str(name).strip()
@@ -47,8 +40,6 @@ class Queue:
 
         # flags
         self._processing = False
-        self._last_msg_hash = None
-        self._requeued = False
         
     def disconnect(self):
         try:
@@ -62,7 +53,12 @@ class Queue:
     def _setup(self):
         self.disconnect()
 
-        parameters = pika.ConnectionParameters(credentials=self.credentials, host=self.host, port=self.port, virtual_host=self.vhost)
+        parameters = pika.ConnectionParameters(
+            credentials=self.credentials,
+            host=self.host, port=self.port,
+            virtual_host=self.vhost,
+            heartbeat=600,
+        )
         self.connection = pika.BlockingConnection(parameters=parameters)                                                
         self.channel = self.connection.channel()
 
@@ -76,7 +72,7 @@ class Queue:
         for _ in range(self.max_retries):
             try:
                 return self._setup()
-            except Errors as e:
+            except pika.exceptions.AMQPError as e:
                 log.error(f'{e}, retrying in 2 secs.')
                 time.sleep(self.retry_interval)
 
@@ -96,7 +92,7 @@ class Queue:
 
         try:
             return self._put(msg, priority=priority)
-        except Errors as e:
+        except pika.exceptions.AMQPError as e:
             log.error(f'{e}, retrying ...')
         
         self.setup()
@@ -105,26 +101,22 @@ class Queue:
     def requeue(self):
         try:
             self.channel.basic_reject(delivery_tag=self._method.delivery_tag, requeue=True)
-        except Errors as e:
+        except pika.exceptions.AMQPError as e:
             log.error(f'{e}, retrying ...')
             self.setup()
 
         self._processing = False
-        self._requeued = True
 
     def task_done(self):
         try:
             self.channel.basic_ack(delivery_tag=self._method.delivery_tag)
-        except Errors as e:
+        except pika.exceptions.AMQPError as e:
             log.error(f'{e}, retrying ...')
             self.setup()
 
         self._processing = False
-        self._requeued = False
-
-    def _move_ahead(self):
-        log.debug('Moving ahead')
 
+    def __next__(self):
         if self._processing:
             raise Exception('The previous message was neither marked done nor requeued.')
 
@@ -134,31 +126,9 @@ class Queue:
             self.setup()
             r = next(self.stream)
 
-        self._method, _, self._body = r
-
-    @property
-    def _msg_hash(self):
-        return md5(self._body).hexdigest()
-
-    @property
-    def _got_old_msg(self):
-        return all([
-            self._method.redelivered,
-            self._msg_hash == self._last_msg_hash,
-            not self._requeued,  # an explicitly requeued message is considered new
-        ])
-
-    def __next__(self):
-        self._move_ahead()
-
-        if self._got_old_msg:
-            log.debug('Got old message')
-            self.task_done()
-            self._move_ahead()
-
+        self._method, _, body = r
         self._processing = True
-        self._last_msg_hash = self._msg_hash
-        return pickle.loads(self._body)
+        return pickle.loads(body)
 
     def __len__(self):
         return self._declare_queue().method.message_count
@@ -184,7 +154,7 @@ class Queue:
     def clear(self):
         try:
             self.channel.queue_purge(queue=self.queue)
-        except Errors as e:
+        except pika.exceptions.AMQPError as e:
             log.error(f'{e}, retrying ...')
             self.setup()
             self.channel.queue_purge(queue=self.queue)
@@ -192,7 +162,7 @@ class Queue:
     def delete(self):
         try:
             self.channel.queue_delete(queue=self.queue)
-        except Errors as e:
+        except pika.exceptions.AMQPError as e:
             log.error(f'{e}, retrying ...')
             self.setup()
             self.channel.queue_delete(queue=self.queue)
